@@ -12,7 +12,7 @@
 #include "collectioninternalspage.h"
 #include "config-akonadiconsole.h"
 #include "tagpropertiesdialog.h"
-#include <Akonadi/ClearCacheJob>
+#include <Akonadi/ClearCacheFoldersJob>
 #include <Akonadi/DbAccess>
 
 #include <Akonadi/AttributeFactory>
@@ -198,12 +198,12 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
 #if ENABLE_CONTENTVIEWS
     auto w = new QWidget;
     w->setLayout(new QVBoxLayout);
-    w->layout()->addWidget(mContactView = new Akonadi::ContactViewer);
+    w->layout()->addWidget(mContactView = new ContactEditor::ContactViewer);
     contentUi.stack->addWidget(w);
 
     w = new QWidget;
     w->setLayout(new QVBoxLayout);
-    w->layout()->addWidget(mContactGroupView = new Akonadi::ContactGroupViewer);
+    w->layout()->addWidget(mContactGroupView = new ContactEditor::ContactGroupViewer);
     contentUi.stack->addWidget(w);
 
     w = new QWidget;
@@ -526,8 +526,7 @@ void BrowserWidget::dumpToXmlResult(KJob *job)
 
 void BrowserWidget::clearCache()
 {
-    Akonadi::ClearCacheJob *job = new Akonadi::ClearCacheJob(this);
-    job->setCollection(currentCollection());
+    auto job = new Akonadi::ClearCacheFoldersJob(currentCollection(), this);
     job->setParentWidget(this);
     job->start();
 }
@@ -583,6 +582,7 @@ void BrowserWidget::tagViewContextMenuRequested(const QPoint &pos)
 void BrowserWidget::addTagRequested()
 {
     auto dlg = new TagPropertiesDialog(this);
+    dlg->setWindowTitle(i18n("Add Tag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::createTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -597,6 +597,7 @@ void BrowserWidget::addSubTagRequested()
     tag.setParent(parentTag);
 
     auto dlg = new TagPropertiesDialog(tag, this);
+    dlg->setWindowTitle(i18n("Add Subtag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::createTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -607,6 +608,7 @@ void BrowserWidget::editTagRequested()
     auto action = qobject_cast<QAction *>(sender());
     const auto tag = action->parent()->property("Tag").value<Akonadi::Tag>();
     auto dlg = new TagPropertiesDialog(tag, this);
+    dlg->setWindowTitle(i18n("Modify Tag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::modifyTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -623,6 +625,7 @@ void BrowserWidget::tagViewDoubleClicked(const QModelIndex &index)
     Q_ASSERT(tag.isValid());
 
     auto dlg = new TagPropertiesDialog(tag, this);
+    dlg->setWindowTitle(i18n("Modify Tag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::modifyTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
